@@ -5,6 +5,7 @@ import json
 from alipay.aop.api.constant.ParamConstants import *
 from alipay.aop.api.domain.ActivityBaseInfo import ActivityBaseInfo
 from alipay.aop.api.domain.VoucherAvailableScopeInfo import VoucherAvailableScopeInfo
+from alipay.aop.api.domain.VoucherCustomerGuideInfo import VoucherCustomerGuideInfo
 from alipay.aop.api.domain.VoucherDeductInfo import VoucherDeductInfo
 from alipay.aop.api.domain.CommonVoucherDisplayLiteInfo import CommonVoucherDisplayLiteInfo
 from alipay.aop.api.domain.VoucherDisplayPatternInfo import VoucherDisplayPatternInfo
@@ -25,6 +26,7 @@ class ActivityLiteInfo(object):
         self._publish_end_time = None
         self._publish_start_time = None
         self._voucher_available_scope_info = None
+        self._voucher_customer_guide_info = None
         self._voucher_deduct_info = None
         self._voucher_display_lite_info = None
         self._voucher_display_pattern_info = None
@@ -103,6 +105,16 @@ class ActivityLiteInfo(object):
         else:
             self._voucher_available_scope_info = VoucherAvailableScopeInfo.from_alipay_dict(value)
     @property
+    def voucher_customer_guide_info(self):
+        return self._voucher_customer_guide_info
+
+    @voucher_customer_guide_info.setter
+    def voucher_customer_guide_info(self, value):
+        if isinstance(value, VoucherCustomerGuideInfo):
+            self._voucher_customer_guide_info = value
+        else:
+            self._voucher_customer_guide_info = VoucherCustomerGuideInfo.from_alipay_dict(value)
+    @property
     def voucher_deduct_info(self):
         return self._voucher_deduct_info
 
@@ -218,6 +230,11 @@ class ActivityLiteInfo(object):
                 params['voucher_available_scope_info'] = self.voucher_available_scope_info.to_alipay_dict()
             else:
                 params['voucher_available_scope_info'] = self.voucher_available_scope_info
+        if self.voucher_customer_guide_info:
+            if hasattr(self.voucher_customer_guide_info, 'to_alipay_dict'):
+                params['voucher_customer_guide_info'] = self.voucher_customer_guide_info.to_alipay_dict()
+            else:
+                params['voucher_customer_guide_info'] = self.voucher_customer_guide_info
         if self.voucher_deduct_info:
             if hasattr(self.voucher_deduct_info, 'to_alipay_dict'):
                 params['voucher_deduct_info'] = self.voucher_deduct_info.to_alipay_dict()
@@ -278,6 +295,8 @@ class ActivityLiteInfo(object):
             o.publish_start_time = d['publish_start_time']
         if 'voucher_available_scope_info' in d:
             o.voucher_available_scope_info = d['voucher_available_scope_info']
+        if 'voucher_customer_guide_info' in d:
+            o.voucher_customer_guide_info = d['voucher_customer_guide_info']
         if 'voucher_deduct_info' in d:
             o.voucher_deduct_info = d['voucher_deduct_info']
         if 'voucher_display_lite_info' in d:
