@@ -5,6 +5,7 @@ import json
 from alipay.aop.api.constant.ParamConstants import *
 from alipay.aop.api.domain.ScenicTrafficUserInfo import ScenicTrafficUserInfo
 from alipay.aop.api.domain.ScenicExtInfo import ScenicExtInfo
+from alipay.aop.api.domain.ScenicExtInfo import ScenicExtInfo
 from alipay.aop.api.domain.ScenicTrafficTicketInfo import ScenicTrafficTicketInfo
 
 
@@ -17,6 +18,7 @@ class AlipayBusinessOrderScenicTrafficSyncModel(object):
         self._contact = None
         self._discount_amount = None
         self._ext_info = None
+        self._ext_infos = None
         self._open_id = None
         self._order_create_time = None
         self._order_id = None
@@ -85,6 +87,19 @@ class AlipayBusinessOrderScenicTrafficSyncModel(object):
         else:
             self._ext_info = ScenicExtInfo.from_alipay_dict(value)
     @property
+    def ext_infos(self):
+        return self._ext_infos
+
+    @ext_infos.setter
+    def ext_infos(self, value):
+        if isinstance(value, list):
+            self._ext_infos = list()
+            for i in value:
+                if isinstance(i, ScenicExtInfo):
+                    self._ext_infos.append(i)
+                else:
+                    self._ext_infos.append(ScenicExtInfo.from_alipay_dict(i))
+    @property
     def open_id(self):
         return self._open_id
 
@@ -250,6 +265,16 @@ class AlipayBusinessOrderScenicTrafficSyncModel(object):
                 params['ext_info'] = self.ext_info.to_alipay_dict()
             else:
                 params['ext_info'] = self.ext_info
+        if self.ext_infos:
+            if isinstance(self.ext_infos, list):
+                for i in range(0, len(self.ext_infos)):
+                    element = self.ext_infos[i]
+                    if hasattr(element, 'to_alipay_dict'):
+                        self.ext_infos[i] = element.to_alipay_dict()
+            if hasattr(self.ext_infos, 'to_alipay_dict'):
+                params['ext_infos'] = self.ext_infos.to_alipay_dict()
+            else:
+                params['ext_infos'] = self.ext_infos
         if self.open_id:
             if hasattr(self.open_id, 'to_alipay_dict'):
                 params['open_id'] = self.open_id.to_alipay_dict()
@@ -364,6 +389,8 @@ class AlipayBusinessOrderScenicTrafficSyncModel(object):
             o.discount_amount = d['discount_amount']
         if 'ext_info' in d:
             o.ext_info = d['ext_info']
+        if 'ext_infos' in d:
+            o.ext_infos = d['ext_infos']
         if 'open_id' in d:
             o.open_id = d['open_id']
         if 'order_create_time' in d:
