@@ -10,6 +10,7 @@ class AlipayCommerceMedicalPaymentCodeGetModel(object):
     def __init__(self):
         self._medical_code = None
         self._org_no = None
+        self._out_request_no = None
 
     @property
     def medical_code(self):
@@ -25,6 +26,13 @@ class AlipayCommerceMedicalPaymentCodeGetModel(object):
     @org_no.setter
     def org_no(self, value):
         self._org_no = value
+    @property
+    def out_request_no(self):
+        return self._out_request_no
+
+    @out_request_no.setter
+    def out_request_no(self, value):
+        self._out_request_no = value
 
 
     def to_alipay_dict(self):
@@ -39,6 +47,11 @@ class AlipayCommerceMedicalPaymentCodeGetModel(object):
                 params['org_no'] = self.org_no.to_alipay_dict()
             else:
                 params['org_no'] = self.org_no
+        if self.out_request_no:
+            if hasattr(self.out_request_no, 'to_alipay_dict'):
+                params['out_request_no'] = self.out_request_no.to_alipay_dict()
+            else:
+                params['out_request_no'] = self.out_request_no
         return params
 
     @staticmethod
@@ -50,6 +63,8 @@ class AlipayCommerceMedicalPaymentCodeGetModel(object):
             o.medical_code = d['medical_code']
         if 'org_no' in d:
             o.org_no = d['org_no']
+        if 'out_request_no' in d:
+            o.out_request_no = d['out_request_no']
         return o
 
 
