@@ -8,10 +8,18 @@ from alipay.aop.api.constant.ParamConstants import *
 class AlipayCommercePayforprivilegeMemberDeleteModel(object):
 
     def __init__(self):
+        self._open_id = None
         self._out_biz_no = None
         self._user_id = None
 
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def out_biz_no(self):
         return self._out_biz_no
 
@@ -29,6 +37,11 @@ class AlipayCommercePayforprivilegeMemberDeleteModel(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.out_biz_no:
             if hasattr(self.out_biz_no, 'to_alipay_dict'):
                 params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
@@ -46,6 +59,8 @@ class AlipayCommercePayforprivilegeMemberDeleteModel(object):
         if not d:
             return None
         o = AlipayCommercePayforprivilegeMemberDeleteModel()
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'out_biz_no' in d:
             o.out_biz_no = d['out_biz_no']
         if 'user_id' in d:
