@@ -11,21 +11,29 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
         self._alipay_order_id = None
         self._apply_scene = None
         self._apply_sub_scene = None
+        self._bank_rule_id = None
+        self._car_type = None
         self._city_code = None
         self._mobile_no = None
+        self._number_of_axles = None
         self._open_id = None
         self._order_censor_status = None
         self._order_pay_status = None
         self._out_order_id = None
         self._plate_color = None
         self._plate_no = None
+        self._product_id = None
         self._seller_id = None
+        self._settlement_cycle = None
         self._spu_code = None
         self._user_id = None
+        self._veh_biz_scene = None
         self._vi_license_apc = None
+        self._vi_license_back_img = None
         self._vi_license_brand_model = None
         self._vi_license_car_type = None
         self._vi_license_engine = None
+        self._vi_license_front_img = None
         self._vi_license_gross_mass = None
         self._vi_license_issue_date = None
         self._vi_license_overall_dinmension = None
@@ -57,6 +65,20 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
     def apply_sub_scene(self, value):
         self._apply_sub_scene = value
     @property
+    def bank_rule_id(self):
+        return self._bank_rule_id
+
+    @bank_rule_id.setter
+    def bank_rule_id(self, value):
+        self._bank_rule_id = value
+    @property
+    def car_type(self):
+        return self._car_type
+
+    @car_type.setter
+    def car_type(self, value):
+        self._car_type = value
+    @property
     def city_code(self):
         return self._city_code
 
@@ -71,6 +93,13 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
     def mobile_no(self, value):
         self._mobile_no = value
     @property
+    def number_of_axles(self):
+        return self._number_of_axles
+
+    @number_of_axles.setter
+    def number_of_axles(self, value):
+        self._number_of_axles = value
+    @property
     def open_id(self):
         return self._open_id
 
@@ -113,6 +142,13 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
     def plate_no(self, value):
         self._plate_no = value
     @property
+    def product_id(self):
+        return self._product_id
+
+    @product_id.setter
+    def product_id(self, value):
+        self._product_id = value
+    @property
     def seller_id(self):
         return self._seller_id
 
@@ -120,6 +156,13 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
     def seller_id(self, value):
         self._seller_id = value
     @property
+    def settlement_cycle(self):
+        return self._settlement_cycle
+
+    @settlement_cycle.setter
+    def settlement_cycle(self, value):
+        self._settlement_cycle = value
+    @property
     def spu_code(self):
         return self._spu_code
 
@@ -134,6 +177,13 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
     def user_id(self, value):
         self._user_id = value
     @property
+    def veh_biz_scene(self):
+        return self._veh_biz_scene
+
+    @veh_biz_scene.setter
+    def veh_biz_scene(self, value):
+        self._veh_biz_scene = value
+    @property
     def vi_license_apc(self):
         return self._vi_license_apc
 
@@ -141,6 +191,13 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
     def vi_license_apc(self, value):
         self._vi_license_apc = value
     @property
+    def vi_license_back_img(self):
+        return self._vi_license_back_img
+
+    @vi_license_back_img.setter
+    def vi_license_back_img(self, value):
+        self._vi_license_back_img = value
+    @property
     def vi_license_brand_model(self):
         return self._vi_license_brand_model
 
@@ -162,6 +219,13 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
     def vi_license_engine(self, value):
         self._vi_license_engine = value
     @property
+    def vi_license_front_img(self):
+        return self._vi_license_front_img
+
+    @vi_license_front_img.setter
+    def vi_license_front_img(self, value):
+        self._vi_license_front_img = value
+    @property
     def vi_license_gross_mass(self):
         return self._vi_license_gross_mass
 
@@ -236,6 +300,16 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
                 params['apply_sub_scene'] = self.apply_sub_scene.to_alipay_dict()
             else:
                 params['apply_sub_scene'] = self.apply_sub_scene
+        if self.bank_rule_id:
+            if hasattr(self.bank_rule_id, 'to_alipay_dict'):
+                params['bank_rule_id'] = self.bank_rule_id.to_alipay_dict()
+            else:
+                params['bank_rule_id'] = self.bank_rule_id
+        if self.car_type:
+            if hasattr(self.car_type, 'to_alipay_dict'):
+                params['car_type'] = self.car_type.to_alipay_dict()
+            else:
+                params['car_type'] = self.car_type
         if self.city_code:
             if hasattr(self.city_code, 'to_alipay_dict'):
                 params['city_code'] = self.city_code.to_alipay_dict()
@@ -246,6 +320,11 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
                 params['mobile_no'] = self.mobile_no.to_alipay_dict()
             else:
                 params['mobile_no'] = self.mobile_no
+        if self.number_of_axles:
+            if hasattr(self.number_of_axles, 'to_alipay_dict'):
+                params['number_of_axles'] = self.number_of_axles.to_alipay_dict()
+            else:
+                params['number_of_axles'] = self.number_of_axles
         if self.open_id:
             if hasattr(self.open_id, 'to_alipay_dict'):
                 params['open_id'] = self.open_id.to_alipay_dict()
@@ -276,11 +355,21 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
                 params['plate_no'] = self.plate_no.to_alipay_dict()
             else:
                 params['plate_no'] = self.plate_no
+        if self.product_id:
+            if hasattr(self.product_id, 'to_alipay_dict'):
+                params['product_id'] = self.product_id.to_alipay_dict()
+            else:
+                params['product_id'] = self.product_id
         if self.seller_id:
             if hasattr(self.seller_id, 'to_alipay_dict'):
                 params['seller_id'] = self.seller_id.to_alipay_dict()
             else:
                 params['seller_id'] = self.seller_id
+        if self.settlement_cycle:
+            if hasattr(self.settlement_cycle, 'to_alipay_dict'):
+                params['settlement_cycle'] = self.settlement_cycle.to_alipay_dict()
+            else:
+                params['settlement_cycle'] = self.settlement_cycle
         if self.spu_code:
             if hasattr(self.spu_code, 'to_alipay_dict'):
                 params['spu_code'] = self.spu_code.to_alipay_dict()
@@ -291,11 +380,21 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
                 params['user_id'] = self.user_id.to_alipay_dict()
             else:
                 params['user_id'] = self.user_id
+        if self.veh_biz_scene:
+            if hasattr(self.veh_biz_scene, 'to_alipay_dict'):
+                params['veh_biz_scene'] = self.veh_biz_scene.to_alipay_dict()
+            else:
+                params['veh_biz_scene'] = self.veh_biz_scene
         if self.vi_license_apc:
             if hasattr(self.vi_license_apc, 'to_alipay_dict'):
                 params['vi_license_apc'] = self.vi_license_apc.to_alipay_dict()
             else:
                 params['vi_license_apc'] = self.vi_license_apc
+        if self.vi_license_back_img:
+            if hasattr(self.vi_license_back_img, 'to_alipay_dict'):
+                params['vi_license_back_img'] = self.vi_license_back_img.to_alipay_dict()
+            else:
+                params['vi_license_back_img'] = self.vi_license_back_img
         if self.vi_license_brand_model:
             if hasattr(self.vi_license_brand_model, 'to_alipay_dict'):
                 params['vi_license_brand_model'] = self.vi_license_brand_model.to_alipay_dict()
@@ -311,6 +410,11 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
                 params['vi_license_engine'] = self.vi_license_engine.to_alipay_dict()
             else:
                 params['vi_license_engine'] = self.vi_license_engine
+        if self.vi_license_front_img:
+            if hasattr(self.vi_license_front_img, 'to_alipay_dict'):
+                params['vi_license_front_img'] = self.vi_license_front_img.to_alipay_dict()
+            else:
+                params['vi_license_front_img'] = self.vi_license_front_img
         if self.vi_license_gross_mass:
             if hasattr(self.vi_license_gross_mass, 'to_alipay_dict'):
                 params['vi_license_gross_mass'] = self.vi_license_gross_mass.to_alipay_dict()
@@ -364,10 +468,16 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
             o.apply_scene = d['apply_scene']
         if 'apply_sub_scene' in d:
             o.apply_sub_scene = d['apply_sub_scene']
+        if 'bank_rule_id' in d:
+            o.bank_rule_id = d['bank_rule_id']
+        if 'car_type' in d:
+            o.car_type = d['car_type']
         if 'city_code' in d:
             o.city_code = d['city_code']
         if 'mobile_no' in d:
             o.mobile_no = d['mobile_no']
+        if 'number_of_axles' in d:
+            o.number_of_axles = d['number_of_axles']
         if 'open_id' in d:
             o.open_id = d['open_id']
         if 'order_censor_status' in d:
@@ -380,20 +490,30 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyModel(object):
             o.plate_color = d['plate_color']
         if 'plate_no' in d:
             o.plate_no = d['plate_no']
+        if 'product_id' in d:
+            o.product_id = d['product_id']
         if 'seller_id' in d:
             o.seller_id = d['seller_id']
+        if 'settlement_cycle' in d:
+            o.settlement_cycle = d['settlement_cycle']
         if 'spu_code' in d:
             o.spu_code = d['spu_code']
         if 'user_id' in d:
             o.user_id = d['user_id']
+        if 'veh_biz_scene' in d:
+            o.veh_biz_scene = d['veh_biz_scene']
         if 'vi_license_apc' in d:
             o.vi_license_apc = d['vi_license_apc']
+        if 'vi_license_back_img' in d:
+            o.vi_license_back_img = d['vi_license_back_img']
         if 'vi_license_brand_model' in d:
             o.vi_license_brand_model = d['vi_license_brand_model']
         if 'vi_license_car_type' in d:
             o.vi_license_car_type = d['vi_license_car_type']
         if 'vi_license_engine' in d:
             o.vi_license_engine = d['vi_license_engine']
+        if 'vi_license_front_img' in d:
+            o.vi_license_front_img = d['vi_license_front_img']
         if 'vi_license_gross_mass' in d:
             o.vi_license_gross_mass = d['vi_license_gross_mass']
         if 'vi_license_issue_date' in d:
