@@ -10,10 +10,12 @@ class AlipayCommerceYuntaskHunterQueryModel(object):
     def __init__(self):
         self._hunter_id = None
         self._hunter_open_id = None
+        self._hunter_phone = None
         self._merchant_pid = None
         self._page = None
         self._page_size = None
         self._shop_id = None
+        self._task_type = None
         self._type = None
 
     @property
@@ -31,6 +33,13 @@ class AlipayCommerceYuntaskHunterQueryModel(object):
     def hunter_open_id(self, value):
         self._hunter_open_id = value
     @property
+    def hunter_phone(self):
+        return self._hunter_phone
+
+    @hunter_phone.setter
+    def hunter_phone(self, value):
+        self._hunter_phone = value
+    @property
     def merchant_pid(self):
         return self._merchant_pid
 
@@ -59,6 +68,13 @@ class AlipayCommerceYuntaskHunterQueryModel(object):
     def shop_id(self, value):
         self._shop_id = value
     @property
+    def task_type(self):
+        return self._task_type
+
+    @task_type.setter
+    def task_type(self, value):
+        self._task_type = value
+    @property
     def type(self):
         return self._type
 
@@ -79,6 +95,11 @@ class AlipayCommerceYuntaskHunterQueryModel(object):
                 params['hunter_open_id'] = self.hunter_open_id.to_alipay_dict()
             else:
                 params['hunter_open_id'] = self.hunter_open_id
+        if self.hunter_phone:
+            if hasattr(self.hunter_phone, 'to_alipay_dict'):
+                params['hunter_phone'] = self.hunter_phone.to_alipay_dict()
+            else:
+                params['hunter_phone'] = self.hunter_phone
         if self.merchant_pid:
             if hasattr(self.merchant_pid, 'to_alipay_dict'):
                 params['merchant_pid'] = self.merchant_pid.to_alipay_dict()
@@ -99,6 +120,11 @@ class AlipayCommerceYuntaskHunterQueryModel(object):
                 params['shop_id'] = self.shop_id.to_alipay_dict()
             else:
                 params['shop_id'] = self.shop_id
+        if self.task_type:
+            if hasattr(self.task_type, 'to_alipay_dict'):
+                params['task_type'] = self.task_type.to_alipay_dict()
+            else:
+                params['task_type'] = self.task_type
         if self.type:
             if hasattr(self.type, 'to_alipay_dict'):
                 params['type'] = self.type.to_alipay_dict()
@@ -115,6 +141,8 @@ class AlipayCommerceYuntaskHunterQueryModel(object):
             o.hunter_id = d['hunter_id']
         if 'hunter_open_id' in d:
             o.hunter_open_id = d['hunter_open_id']
+        if 'hunter_phone' in d:
+            o.hunter_phone = d['hunter_phone']
         if 'merchant_pid' in d:
             o.merchant_pid = d['merchant_pid']
         if 'page' in d:
@@ -123,6 +151,8 @@ class AlipayCommerceYuntaskHunterQueryModel(object):
             o.page_size = d['page_size']
         if 'shop_id' in d:
             o.shop_id = d['shop_id']
+        if 'task_type' in d:
+            o.task_type = d['task_type']
         if 'type' in d:
             o.type = d['type']
         return o
