@@ -14,6 +14,7 @@ class AlipayDataBillAccountlogQueryModel(object):
         self._bill_user_id = None
         self._end_time = None
         self._merchant_order_no = None
+        self._open_id = None
         self._page_no = None
         self._page_size = None
         self._start_time = None
@@ -62,6 +63,13 @@ class AlipayDataBillAccountlogQueryModel(object):
     def merchant_order_no(self, value):
         self._merchant_order_no = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def page_no(self):
         return self._page_no
 
@@ -123,6 +131,11 @@ class AlipayDataBillAccountlogQueryModel(object):
                 params['merchant_order_no'] = self.merchant_order_no.to_alipay_dict()
             else:
                 params['merchant_order_no'] = self.merchant_order_no
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.page_no:
             if hasattr(self.page_no, 'to_alipay_dict'):
                 params['page_no'] = self.page_no.to_alipay_dict()
@@ -162,6 +175,8 @@ class AlipayDataBillAccountlogQueryModel(object):
             o.end_time = d['end_time']
         if 'merchant_order_no' in d:
             o.merchant_order_no = d['merchant_order_no']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'page_no' in d:
             o.page_no = d['page_no']
         if 'page_size' in d:
