@@ -11,6 +11,7 @@ class AlipayMarketingActivityUserQueryvoucherModel(object):
         self._activity_id = None
         self._merchant_access_mode = None
         self._merchant_id = None
+        self._open_id = None
         self._user_id = None
         self._voucher_code = None
         self._voucher_id = None
@@ -37,6 +38,13 @@ class AlipayMarketingActivityUserQueryvoucherModel(object):
     def merchant_id(self, value):
         self._merchant_id = value
     @property
+    def open_id(self):
+        return self._open_id
+
+    @open_id.setter
+    def open_id(self, value):
+        self._open_id = value
+    @property
     def user_id(self):
         return self._user_id
 
@@ -76,6 +84,11 @@ class AlipayMarketingActivityUserQueryvoucherModel(object):
                 params['merchant_id'] = self.merchant_id.to_alipay_dict()
             else:
                 params['merchant_id'] = self.merchant_id
+        if self.open_id:
+            if hasattr(self.open_id, 'to_alipay_dict'):
+                params['open_id'] = self.open_id.to_alipay_dict()
+            else:
+                params['open_id'] = self.open_id
         if self.user_id:
             if hasattr(self.user_id, 'to_alipay_dict'):
                 params['user_id'] = self.user_id.to_alipay_dict()
@@ -104,6 +117,8 @@ class AlipayMarketingActivityUserQueryvoucherModel(object):
             o.merchant_access_mode = d['merchant_access_mode']
         if 'merchant_id' in d:
             o.merchant_id = d['merchant_id']
+        if 'open_id' in d:
+            o.open_id = d['open_id']
         if 'user_id' in d:
             o.user_id = d['user_id']
         if 'voucher_code' in d:
