@@ -13,7 +13,9 @@ class AlipayOpenAppItemCreateModel(object):
 
     def __init__(self):
         self._attrs = None
+        self._auto_marketing_delivery = None
         self._barcode = None
+        self._business_model = None
         self._category_id = None
         self._desc = None
         self._desc_info = None
@@ -29,6 +31,7 @@ class AlipayOpenAppItemCreateModel(object):
         self._price_unit = None
         self._sale_price = None
         self._sale_status = None
+        self._skip_algorithm_check = None
         self._skus = None
         self._stock_num = None
         self._title = None
@@ -47,6 +50,13 @@ class AlipayOpenAppItemCreateModel(object):
                 else:
                     self._attrs.append(AppItemAttrVO.from_alipay_dict(i))
     @property
+    def auto_marketing_delivery(self):
+        return self._auto_marketing_delivery
+
+    @auto_marketing_delivery.setter
+    def auto_marketing_delivery(self, value):
+        self._auto_marketing_delivery = value
+    @property
     def barcode(self):
         return self._barcode
 
@@ -54,6 +64,13 @@ class AlipayOpenAppItemCreateModel(object):
     def barcode(self, value):
         self._barcode = value
     @property
+    def business_model(self):
+        return self._business_model
+
+    @business_model.setter
+    def business_model(self, value):
+        self._business_model = value
+    @property
     def category_id(self):
         return self._category_id
 
@@ -171,6 +188,13 @@ class AlipayOpenAppItemCreateModel(object):
     def sale_status(self, value):
         self._sale_status = value
     @property
+    def skip_algorithm_check(self):
+        return self._skip_algorithm_check
+
+    @skip_algorithm_check.setter
+    def skip_algorithm_check(self, value):
+        self._skip_algorithm_check = value
+    @property
     def skus(self):
         return self._skus
 
@@ -211,11 +235,21 @@ class AlipayOpenAppItemCreateModel(object):
                 params['attrs'] = self.attrs.to_alipay_dict()
             else:
                 params['attrs'] = self.attrs
+        if self.auto_marketing_delivery:
+            if hasattr(self.auto_marketing_delivery, 'to_alipay_dict'):
+                params['auto_marketing_delivery'] = self.auto_marketing_delivery.to_alipay_dict()
+            else:
+                params['auto_marketing_delivery'] = self.auto_marketing_delivery
         if self.barcode:
             if hasattr(self.barcode, 'to_alipay_dict'):
                 params['barcode'] = self.barcode.to_alipay_dict()
             else:
                 params['barcode'] = self.barcode
+        if self.business_model:
+            if hasattr(self.business_model, 'to_alipay_dict'):
+                params['business_model'] = self.business_model.to_alipay_dict()
+            else:
+                params['business_model'] = self.business_model
         if self.category_id:
             if hasattr(self.category_id, 'to_alipay_dict'):
                 params['category_id'] = self.category_id.to_alipay_dict()
@@ -301,6 +335,11 @@ class AlipayOpenAppItemCreateModel(object):
                 params['sale_status'] = self.sale_status.to_alipay_dict()
             else:
                 params['sale_status'] = self.sale_status
+        if self.skip_algorithm_check:
+            if hasattr(self.skip_algorithm_check, 'to_alipay_dict'):
+                params['skip_algorithm_check'] = self.skip_algorithm_check.to_alipay_dict()
+            else:
+                params['skip_algorithm_check'] = self.skip_algorithm_check
         if self.skus:
             if isinstance(self.skus, list):
                 for i in range(0, len(self.skus)):
@@ -330,8 +369,12 @@ class AlipayOpenAppItemCreateModel(object):
         o = AlipayOpenAppItemCreateModel()
         if 'attrs' in d:
             o.attrs = d['attrs']
+        if 'auto_marketing_delivery' in d:
+            o.auto_marketing_delivery = d['auto_marketing_delivery']
         if 'barcode' in d:
             o.barcode = d['barcode']
+        if 'business_model' in d:
+            o.business_model = d['business_model']
         if 'category_id' in d:
             o.category_id = d['category_id']
         if 'desc' in d:
@@ -362,6 +405,8 @@ class AlipayOpenAppItemCreateModel(object):
             o.sale_price = d['sale_price']
         if 'sale_status' in d:
             o.sale_status = d['sale_status']
+        if 'skip_algorithm_check' in d:
+            o.skip_algorithm_check = d['skip_algorithm_check']
         if 'skus' in d:
             o.skus = d['skus']
         if 'stock_num' in d:
