@@ -4,15 +4,20 @@ import json
 
 from alipay.aop.api.constant.ParamConstants import *
 from alipay.aop.api.domain.MiniReceiverAddressInfoDTO import MiniReceiverAddressInfoDTO
+from alipay.aop.api.domain.AgreementSignInfoDTO import AgreementSignInfoDTO
+from alipay.aop.api.domain.AllocAmountInfoDTO import AllocAmountInfoDTO
 from alipay.aop.api.domain.MiniBusinessParamsDTO import MiniBusinessParamsDTO
 from alipay.aop.api.domain.ContactInfoDTO import ContactInfoDTO
 from alipay.aop.api.domain.CreditInfoDTO import CreditInfoDTO
 from alipay.aop.api.domain.MiniReceiverAddressInfoDTO import MiniReceiverAddressInfoDTO
 from alipay.aop.api.domain.LogisticsInfoDTO import LogisticsInfoDTO
 from alipay.aop.api.domain.MiniOrderExtInfoDTO import MiniOrderExtInfoDTO
+from alipay.aop.api.domain.FundAuthFreezeInfoDTO import FundAuthFreezeInfoDTO
 from alipay.aop.api.domain.MiniOrderDetailDTO import MiniOrderDetailDTO
 from alipay.aop.api.domain.PromoDetailInfoDTO import PromoDetailInfoDTO
+from alipay.aop.api.domain.MiniOrderAddressInfoDTO import MiniOrderAddressInfoDTO
 from alipay.aop.api.domain.ShopInfoDTO import ShopInfoDTO
+from alipay.aop.api.domain.StagePayPlanDTO import StagePayPlanDTO
 from alipay.aop.api.domain.SubMerchantDTO import SubMerchantDTO
 
 
@@ -20,26 +25,36 @@ class AlipayOpenMiniOrderCreateModel(object):
 
     def __init__(self):
         self._address_info = None
+        self._agreement_sign_info = None
+        self._alloc_amount_info = None
         self._business_params = None
         self._buyer_id = None
         self._buyer_logon_id = None
         self._buyer_open_id = None
+        self._confirm_timeout_express = None
         self._contact_info = None
         self._credit_info = None
         self._default_receiving_address = None
         self._delivery_detail = None
         self._ext_info = None
+        self._fund_auth_freeze_info = None
+        self._memo = None
         self._merchant_biz_type = None
         self._order_detail = None
         self._out_order_id = None
         self._path = None
         self._promo_detail_info = None
         self._seller_id = None
+        self._send_address_info = None
+        self._service_provider_model = None
+        self._service_type = None
         self._shop_info = None
         self._source_id = None
+        self._stage_pay_plans = None
         self._sub_merchant = None
         self._timeout_express = None
         self._title = None
+        self._trade_app_id = None
 
     @property
     def address_info(self):
@@ -52,6 +67,26 @@ class AlipayOpenMiniOrderCreateModel(object):
         else:
             self._address_info = MiniReceiverAddressInfoDTO.from_alipay_dict(value)
     @property
+    def agreement_sign_info(self):
+        return self._agreement_sign_info
+
+    @agreement_sign_info.setter
+    def agreement_sign_info(self, value):
+        if isinstance(value, AgreementSignInfoDTO):
+            self._agreement_sign_info = value
+        else:
+            self._agreement_sign_info = AgreementSignInfoDTO.from_alipay_dict(value)
+    @property
+    def alloc_amount_info(self):
+        return self._alloc_amount_info
+
+    @alloc_amount_info.setter
+    def alloc_amount_info(self, value):
+        if isinstance(value, AllocAmountInfoDTO):
+            self._alloc_amount_info = value
+        else:
+            self._alloc_amount_info = AllocAmountInfoDTO.from_alipay_dict(value)
+    @property
     def business_params(self):
         return self._business_params
 
@@ -83,6 +118,13 @@ class AlipayOpenMiniOrderCreateModel(object):
     def buyer_open_id(self, value):
         self._buyer_open_id = value
     @property
+    def confirm_timeout_express(self):
+        return self._confirm_timeout_express
+
+    @confirm_timeout_express.setter
+    def confirm_timeout_express(self, value):
+        self._confirm_timeout_express = value
+    @property
     def contact_info(self):
         return self._contact_info
 
@@ -133,6 +175,23 @@ class AlipayOpenMiniOrderCreateModel(object):
         else:
             self._ext_info = MiniOrderExtInfoDTO.from_alipay_dict(value)
     @property
+    def fund_auth_freeze_info(self):
+        return self._fund_auth_freeze_info
+
+    @fund_auth_freeze_info.setter
+    def fund_auth_freeze_info(self, value):
+        if isinstance(value, FundAuthFreezeInfoDTO):
+            self._fund_auth_freeze_info = value
+        else:
+            self._fund_auth_freeze_info = FundAuthFreezeInfoDTO.from_alipay_dict(value)
+    @property
+    def memo(self):
+        return self._memo
+
+    @memo.setter
+    def memo(self, value):
+        self._memo = value
+    @property
     def merchant_biz_type(self):
         return self._merchant_biz_type
 
@@ -181,6 +240,30 @@ class AlipayOpenMiniOrderCreateModel(object):
     def seller_id(self, value):
         self._seller_id = value
     @property
+    def send_address_info(self):
+        return self._send_address_info
+
+    @send_address_info.setter
+    def send_address_info(self, value):
+        if isinstance(value, MiniOrderAddressInfoDTO):
+            self._send_address_info = value
+        else:
+            self._send_address_info = MiniOrderAddressInfoDTO.from_alipay_dict(value)
+    @property
+    def service_provider_model(self):
+        return self._service_provider_model
+
+    @service_provider_model.setter
+    def service_provider_model(self, value):
+        self._service_provider_model = value
+    @property
+    def service_type(self):
+        return self._service_type
+
+    @service_type.setter
+    def service_type(self, value):
+        self._service_type = value
+    @property
     def shop_info(self):
         return self._shop_info
 
@@ -198,6 +281,19 @@ class AlipayOpenMiniOrderCreateModel(object):
     def source_id(self, value):
         self._source_id = value
     @property
+    def stage_pay_plans(self):
+        return self._stage_pay_plans
+
+    @stage_pay_plans.setter
+    def stage_pay_plans(self, value):
+        if isinstance(value, list):
+            self._stage_pay_plans = list()
+            for i in value:
+                if isinstance(i, StagePayPlanDTO):
+                    self._stage_pay_plans.append(i)
+                else:
+                    self._stage_pay_plans.append(StagePayPlanDTO.from_alipay_dict(i))
+    @property
     def sub_merchant(self):
         return self._sub_merchant
 
@@ -221,6 +317,13 @@ class AlipayOpenMiniOrderCreateModel(object):
     @title.setter
     def title(self, value):
         self._title = value
+    @property
+    def trade_app_id(self):
+        return self._trade_app_id
+
+    @trade_app_id.setter
+    def trade_app_id(self, value):
+        self._trade_app_id = value
 
 
     def to_alipay_dict(self):
@@ -230,6 +333,16 @@ class AlipayOpenMiniOrderCreateModel(object):
                 params['address_info'] = self.address_info.to_alipay_dict()
             else:
                 params['address_info'] = self.address_info
+        if self.agreement_sign_info:
+            if hasattr(self.agreement_sign_info, 'to_alipay_dict'):
+                params['agreement_sign_info'] = self.agreement_sign_info.to_alipay_dict()
+            else:
+                params['agreement_sign_info'] = self.agreement_sign_info
+        if self.alloc_amount_info:
+            if hasattr(self.alloc_amount_info, 'to_alipay_dict'):
+                params['alloc_amount_info'] = self.alloc_amount_info.to_alipay_dict()
+            else:
+                params['alloc_amount_info'] = self.alloc_amount_info
         if self.business_params:
             if hasattr(self.business_params, 'to_alipay_dict'):
                 params['business_params'] = self.business_params.to_alipay_dict()
@@ -250,6 +363,11 @@ class AlipayOpenMiniOrderCreateModel(object):
                 params['buyer_open_id'] = self.buyer_open_id.to_alipay_dict()
             else:
                 params['buyer_open_id'] = self.buyer_open_id
+        if self.confirm_timeout_express:
+            if hasattr(self.confirm_timeout_express, 'to_alipay_dict'):
+                params['confirm_timeout_express'] = self.confirm_timeout_express.to_alipay_dict()
+            else:
+                params['confirm_timeout_express'] = self.confirm_timeout_express
         if self.contact_info:
             if hasattr(self.contact_info, 'to_alipay_dict'):
                 params['contact_info'] = self.contact_info.to_alipay_dict()
@@ -275,6 +393,16 @@ class AlipayOpenMiniOrderCreateModel(object):
                 params['ext_info'] = self.ext_info.to_alipay_dict()
             else:
                 params['ext_info'] = self.ext_info
+        if self.fund_auth_freeze_info:
+            if hasattr(self.fund_auth_freeze_info, 'to_alipay_dict'):
+                params['fund_auth_freeze_info'] = self.fund_auth_freeze_info.to_alipay_dict()
+            else:
+                params['fund_auth_freeze_info'] = self.fund_auth_freeze_info
+        if self.memo:
+            if hasattr(self.memo, 'to_alipay_dict'):
+                params['memo'] = self.memo.to_alipay_dict()
+            else:
+                params['memo'] = self.memo
         if self.merchant_biz_type:
             if hasattr(self.merchant_biz_type, 'to_alipay_dict'):
                 params['merchant_biz_type'] = self.merchant_biz_type.to_alipay_dict()
@@ -305,6 +433,21 @@ class AlipayOpenMiniOrderCreateModel(object):
                 params['seller_id'] = self.seller_id.to_alipay_dict()
             else:
                 params['seller_id'] = self.seller_id
+        if self.send_address_info:
+            if hasattr(self.send_address_info, 'to_alipay_dict'):
+                params['send_address_info'] = self.send_address_info.to_alipay_dict()
+            else:
+                params['send_address_info'] = self.send_address_info
+        if self.service_provider_model:
+            if hasattr(self.service_provider_model, 'to_alipay_dict'):
+                params['service_provider_model'] = self.service_provider_model.to_alipay_dict()
+            else:
+                params['service_provider_model'] = self.service_provider_model
+        if self.service_type:
+            if hasattr(self.service_type, 'to_alipay_dict'):
+                params['service_type'] = self.service_type.to_alipay_dict()
+            else:
+                params['service_type'] = self.service_type
         if self.shop_info:
             if hasattr(self.shop_info, 'to_alipay_dict'):
                 params['shop_info'] = self.shop_info.to_alipay_dict()
@@ -315,6 +458,16 @@ class AlipayOpenMiniOrderCreateModel(object):
                 params['source_id'] = self.source_id.to_alipay_dict()
             else:
                 params['source_id'] = self.source_id
+        if self.stage_pay_plans:
+            if isinstance(self.stage_pay_plans, list):
+                for i in range(0, len(self.stage_pay_plans)):
+                    element = self.stage_pay_plans[i]
+                    if hasattr(element, 'to_alipay_dict'):
+                        self.stage_pay_plans[i] = element.to_alipay_dict()
+            if hasattr(self.stage_pay_plans, 'to_alipay_dict'):
+                params['stage_pay_plans'] = self.stage_pay_plans.to_alipay_dict()
+            else:
+                params['stage_pay_plans'] = self.stage_pay_plans
         if self.sub_merchant:
             if hasattr(self.sub_merchant, 'to_alipay_dict'):
                 params['sub_merchant'] = self.sub_merchant.to_alipay_dict()
@@ -330,6 +483,11 @@ class AlipayOpenMiniOrderCreateModel(object):
                 params['title'] = self.title.to_alipay_dict()
             else:
                 params['title'] = self.title
+        if self.trade_app_id:
+            if hasattr(self.trade_app_id, 'to_alipay_dict'):
+                params['trade_app_id'] = self.trade_app_id.to_alipay_dict()
+            else:
+                params['trade_app_id'] = self.trade_app_id
         return params
 
     @staticmethod
@@ -339,6 +497,10 @@ class AlipayOpenMiniOrderCreateModel(object):
         o = AlipayOpenMiniOrderCreateModel()
         if 'address_info' in d:
             o.address_info = d['address_info']
+        if 'agreement_sign_info' in d:
+            o.agreement_sign_info = d['agreement_sign_info']
+        if 'alloc_amount_info' in d:
+            o.alloc_amount_info = d['alloc_amount_info']
         if 'business_params' in d:
             o.business_params = d['business_params']
         if 'buyer_id' in d:
@@ -347,6 +509,8 @@ class AlipayOpenMiniOrderCreateModel(object):
             o.buyer_logon_id = d['buyer_logon_id']
         if 'buyer_open_id' in d:
             o.buyer_open_id = d['buyer_open_id']
+        if 'confirm_timeout_express' in d:
+            o.confirm_timeout_express = d['confirm_timeout_express']
         if 'contact_info' in d:
             o.contact_info = d['contact_info']
         if 'credit_info' in d:
@@ -357,6 +521,10 @@ class AlipayOpenMiniOrderCreateModel(object):
             o.delivery_detail = d['delivery_detail']
         if 'ext_info' in d:
             o.ext_info = d['ext_info']
+        if 'fund_auth_freeze_info' in d:
+            o.fund_auth_freeze_info = d['fund_auth_freeze_info']
+        if 'memo' in d:
+            o.memo = d['memo']
         if 'merchant_biz_type' in d:
             o.merchant_biz_type = d['merchant_biz_type']
         if 'order_detail' in d:
@@ -369,16 +537,26 @@ class AlipayOpenMiniOrderCreateModel(object):
             o.promo_detail_info = d['promo_detail_info']
         if 'seller_id' in d:
             o.seller_id = d['seller_id']
+        if 'send_address_info' in d:
+            o.send_address_info = d['send_address_info']
+        if 'service_provider_model' in d:
+            o.service_provider_model = d['service_provider_model']
+        if 'service_type' in d:
+            o.service_type = d['service_type']
         if 'shop_info' in d:
             o.shop_info = d['shop_info']
         if 'source_id' in d:
             o.source_id = d['source_id']
+        if 'stage_pay_plans' in d:
+            o.stage_pay_plans = d['stage_pay_plans']
         if 'sub_merchant' in d:
             o.sub_merchant = d['sub_merchant']
         if 'timeout_express' in d:
             o.timeout_express = d['timeout_express']
         if 'title' in d:
             o.title = d['title']
+        if 'trade_app_id' in d:
+            o.trade_app_id = d['trade_app_id']
         return o
 
 
