@@ -9,6 +9,7 @@ class AlipayOpenOperationOpenbizmockTestnumberQueryModel(object):
 
     def __init__(self):
         self._a = None
+        self._b = None
         self._keykey = None
 
     @property
@@ -19,6 +20,13 @@ class AlipayOpenOperationOpenbizmockTestnumberQueryModel(object):
     def a(self, value):
         self._a = value
     @property
+    def b(self):
+        return self._b
+
+    @b.setter
+    def b(self, value):
+        self._b = value
+    @property
     def keykey(self):
         return self._keykey
 
@@ -34,6 +42,11 @@ class AlipayOpenOperationOpenbizmockTestnumberQueryModel(object):
                 params['a'] = self.a.to_alipay_dict()
             else:
                 params['a'] = self.a
+        if self.b:
+            if hasattr(self.b, 'to_alipay_dict'):
+                params['b'] = self.b.to_alipay_dict()
+            else:
+                params['b'] = self.b
         if self.keykey:
             if hasattr(self.keykey, 'to_alipay_dict'):
                 params['keykey'] = self.keykey.to_alipay_dict()
@@ -48,6 +61,8 @@ class AlipayOpenOperationOpenbizmockTestnumberQueryModel(object):
         o = AlipayOpenOperationOpenbizmockTestnumberQueryModel()
         if 'a' in d:
             o.a = d['a']
+        if 'b' in d:
+            o.b = d['b']
         if 'keykey' in d:
             o.keykey = d['keykey']
         return o
