@@ -31,6 +31,7 @@ class AlipayTradeAppPayModel(object):
         self._passback_params = None
         self._product_code = None
         self._promo_params = None
+        self._query_options = None
         self._royalty_info = None
         self._seller_id = None
         self._settle_info = None
@@ -166,6 +167,16 @@ class AlipayTradeAppPayModel(object):
     def promo_params(self, value):
         self._promo_params = value
     @property
+    def query_options(self):
+        return self._query_options
+
+    @query_options.setter
+    def query_options(self, value):
+        if isinstance(value, list):
+            self._query_options = list()
+            for i in value:
+                self._query_options.append(i)
+    @property
     def royalty_info(self):
         return self._royalty_info
 
@@ -328,6 +339,16 @@ class AlipayTradeAppPayModel(object):
                 params['promo_params'] = self.promo_params.to_alipay_dict()
             else:
                 params['promo_params'] = self.promo_params
+        if self.query_options:
+            if isinstance(self.query_options, list):
+                for i in range(0, len(self.query_options)):
+                    element = self.query_options[i]
+                    if hasattr(element, 'to_alipay_dict'):
+                        self.query_options[i] = element.to_alipay_dict()
+            if hasattr(self.query_options, 'to_alipay_dict'):
+                params['query_options'] = self.query_options.to_alipay_dict()
+            else:
+                params['query_options'] = self.query_options
         if self.royalty_info:
             if hasattr(self.royalty_info, 'to_alipay_dict'):
                 params['royalty_info'] = self.royalty_info.to_alipay_dict()
@@ -415,6 +436,8 @@ class AlipayTradeAppPayModel(object):
             o.product_code = d['product_code']
         if 'promo_params' in d:
             o.promo_params = d['promo_params']
+        if 'query_options' in d:
+            o.query_options = d['query_options']
         if 'royalty_info' in d:
             o.royalty_info = d['royalty_info']
         if 'seller_id' in d:
