@@ -3,6 +3,7 @@
 import json
 
 from alipay.aop.api.constant.ParamConstants import *
+from alipay.aop.api.domain.SignParams import SignParams
 from alipay.aop.api.domain.BkAgentReqInfo import BkAgentReqInfo
 from alipay.aop.api.domain.BusinessParams import BusinessParams
 from alipay.aop.api.domain.ExtUserInfo import ExtUserInfo
@@ -18,6 +19,7 @@ from alipay.aop.api.domain.SubMerchant import SubMerchant
 class AlipayTradeCreateModel(object):
 
     def __init__(self):
+        self._agreement_sign_params = None
         self._alipay_store_id = None
         self._bkagent_req_info = None
         self._body = None
@@ -33,6 +35,8 @@ class AlipayTradeCreateModel(object):
         self._goods_detail = None
         self._logistics_detail = None
         self._merchant_order_no = None
+        self._op_app_id = None
+        self._op_buyer_open_id = None
         self._operator_id = None
         self._out_trade_no = None
         self._passback_params = None
@@ -52,6 +56,16 @@ class AlipayTradeCreateModel(object):
         self._undiscountable_amount = None
 
     @property
+    def agreement_sign_params(self):
+        return self._agreement_sign_params
+
+    @agreement_sign_params.setter
+    def agreement_sign_params(self, value):
+        if isinstance(value, SignParams):
+            self._agreement_sign_params = value
+        else:
+            self._agreement_sign_params = SignParams.from_alipay_dict(value)
+    @property
     def alipay_store_id(self):
         return self._alipay_store_id
 
@@ -178,6 +192,20 @@ class AlipayTradeCreateModel(object):
     def merchant_order_no(self, value):
         self._merchant_order_no = value
     @property
+    def op_app_id(self):
+        return self._op_app_id
+
+    @op_app_id.setter
+    def op_app_id(self, value):
+        self._op_app_id = value
+    @property
+    def op_buyer_open_id(self):
+        return self._op_buyer_open_id
+
+    @op_buyer_open_id.setter
+    def op_buyer_open_id(self, value):
+        self._op_buyer_open_id = value
+    @property
     def operator_id(self):
         return self._operator_id
 
@@ -315,6 +343,11 @@ class AlipayTradeCreateModel(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.agreement_sign_params:
+            if hasattr(self.agreement_sign_params, 'to_alipay_dict'):
+                params['agreement_sign_params'] = self.agreement_sign_params.to_alipay_dict()
+            else:
+                params['agreement_sign_params'] = self.agreement_sign_params
         if self.alipay_store_id:
             if hasattr(self.alipay_store_id, 'to_alipay_dict'):
                 params['alipay_store_id'] = self.alipay_store_id.to_alipay_dict()
@@ -395,6 +428,16 @@ class AlipayTradeCreateModel(object):
                 params['merchant_order_no'] = self.merchant_order_no.to_alipay_dict()
             else:
                 params['merchant_order_no'] = self.merchant_order_no
+        if self.op_app_id:
+            if hasattr(self.op_app_id, 'to_alipay_dict'):
+                params['op_app_id'] = self.op_app_id.to_alipay_dict()
+            else:
+                params['op_app_id'] = self.op_app_id
+        if self.op_buyer_open_id:
+            if hasattr(self.op_buyer_open_id, 'to_alipay_dict'):
+                params['op_buyer_open_id'] = self.op_buyer_open_id.to_alipay_dict()
+            else:
+                params['op_buyer_open_id'] = self.op_buyer_open_id
         if self.operator_id:
             if hasattr(self.operator_id, 'to_alipay_dict'):
                 params['operator_id'] = self.operator_id.to_alipay_dict()
@@ -492,6 +535,8 @@ class AlipayTradeCreateModel(object):
         if not d:
             return None
         o = AlipayTradeCreateModel()
+        if 'agreement_sign_params' in d:
+            o.agreement_sign_params = d['agreement_sign_params']
         if 'alipay_store_id' in d:
             o.alipay_store_id = d['alipay_store_id']
         if 'bkagent_req_info' in d:
@@ -522,6 +567,10 @@ class AlipayTradeCreateModel(object):
             o.logistics_detail = d['logistics_detail']
         if 'merchant_order_no' in d:
             o.merchant_order_no = d['merchant_order_no']
+        if 'op_app_id' in d:
+            o.op_app_id = d['op_app_id']
+        if 'op_buyer_open_id' in d:
+            o.op_buyer_open_id = d['op_buyer_open_id']
         if 'operator_id' in d:
             o.operator_id = d['operator_id']
         if 'out_trade_no' in d:
