@@ -16,6 +16,7 @@ class AlipayUserAgreementSignModel(object):
 
     def __init__(self):
         self._alipay_logon_id = None
+        self._alipay_open_id = None
         self._alipay_user_id = None
         self._asset_params = None
         self._binded_mobile = None
@@ -47,6 +48,13 @@ class AlipayUserAgreementSignModel(object):
     def alipay_logon_id(self, value):
         self._alipay_logon_id = value
     @property
+    def alipay_open_id(self):
+        return self._alipay_open_id
+
+    @alipay_open_id.setter
+    def alipay_open_id(self, value):
+        self._alipay_open_id = value
+    @property
     def alipay_user_id(self):
         return self._alipay_user_id
 
@@ -233,6 +241,11 @@ class AlipayUserAgreementSignModel(object):
                 params['alipay_logon_id'] = self.alipay_logon_id.to_alipay_dict()
             else:
                 params['alipay_logon_id'] = self.alipay_logon_id
+        if self.alipay_open_id:
+            if hasattr(self.alipay_open_id, 'to_alipay_dict'):
+                params['alipay_open_id'] = self.alipay_open_id.to_alipay_dict()
+            else:
+                params['alipay_open_id'] = self.alipay_open_id
         if self.alipay_user_id:
             if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                 params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
@@ -357,6 +370,8 @@ class AlipayUserAgreementSignModel(object):
         o = AlipayUserAgreementSignModel()
         if 'alipay_logon_id' in d:
             o.alipay_logon_id = d['alipay_logon_id']
+        if 'alipay_open_id' in d:
+            o.alipay_open_id = d['alipay_open_id']
         if 'alipay_user_id' in d:
             o.alipay_user_id = d['alipay_user_id']
         if 'asset_params' in d:
