@@ -12,6 +12,7 @@ class AssetBomItem(object):
         self._count = None
         self._item_id = None
         self._item_name = None
+        self._item_version = None
         self._release_status = None
         self._status = None
 
@@ -44,6 +45,13 @@ class AssetBomItem(object):
     def item_name(self, value):
         self._item_name = value
     @property
+    def item_version(self):
+        return self._item_version
+
+    @item_version.setter
+    def item_version(self, value):
+        self._item_version = value
+    @property
     def release_status(self):
         return self._release_status
 
@@ -81,6 +89,11 @@ class AssetBomItem(object):
                 params['item_name'] = self.item_name.to_alipay_dict()
             else:
                 params['item_name'] = self.item_name
+        if self.item_version:
+            if hasattr(self.item_version, 'to_alipay_dict'):
+                params['item_version'] = self.item_version.to_alipay_dict()
+            else:
+                params['item_version'] = self.item_version
         if self.release_status:
             if hasattr(self.release_status, 'to_alipay_dict'):
                 params['release_status'] = self.release_status.to_alipay_dict()
@@ -106,6 +119,8 @@ class AssetBomItem(object):
             o.item_id = d['item_id']
         if 'item_name' in d:
             o.item_name = d['item_name']
+        if 'item_version' in d:
+            o.item_version = d['item_version']
         if 'release_status' in d:
             o.release_status = d['release_status']
         if 'status' in d:
