@@ -17,15 +17,23 @@ class CrowdSelectTagOpenRequest(object):
 
     @select_tag_values.setter
     def select_tag_values(self, value):
-        if isinstance(value, CrowdSelectTagValuesOpenRequest):
-            self._select_tag_values = value
-        else:
-            self._select_tag_values = CrowdSelectTagValuesOpenRequest.from_alipay_dict(value)
+        if isinstance(value, list):
+            self._select_tag_values = list()
+            for i in value:
+                if isinstance(i, CrowdSelectTagValuesOpenRequest):
+                    self._select_tag_values.append(i)
+                else:
+                    self._select_tag_values.append(CrowdSelectTagValuesOpenRequest.from_alipay_dict(i))
 
 
     def to_alipay_dict(self):
         params = dict()
         if self.select_tag_values:
+            if isinstance(self.select_tag_values, list):
+                for i in range(0, len(self.select_tag_values)):
+                    element = self.select_tag_values[i]
+                    if hasattr(element, 'to_alipay_dict'):
+                        self.select_tag_values[i] = element.to_alipay_dict()
             if hasattr(self.select_tag_values, 'to_alipay_dict'):
                 params['select_tag_values'] = self.select_tag_values.to_alipay_dict()
             else:
