@@ -12,9 +12,11 @@ class InquiryChannel(object):
         self._inquiry_doctor_shift_case_list = None
         self._inquiry_mode = None
         self._inquiry_price = None
+        self._inquiry_status = None
         self._inquiry_type = None
         self._inquiry_url = None
         self._register_flag = None
+        self._service_duration = None
 
     @property
     def inquiry_doctor_shift_case_list(self):
@@ -44,6 +46,13 @@ class InquiryChannel(object):
     def inquiry_price(self, value):
         self._inquiry_price = value
     @property
+    def inquiry_status(self):
+        return self._inquiry_status
+
+    @inquiry_status.setter
+    def inquiry_status(self, value):
+        self._inquiry_status = value
+    @property
     def inquiry_type(self):
         return self._inquiry_type
 
@@ -64,6 +73,13 @@ class InquiryChannel(object):
     @register_flag.setter
     def register_flag(self, value):
         self._register_flag = value
+    @property
+    def service_duration(self):
+        return self._service_duration
+
+    @service_duration.setter
+    def service_duration(self, value):
+        self._service_duration = value
 
 
     def to_alipay_dict(self):
@@ -88,6 +104,11 @@ class InquiryChannel(object):
                 params['inquiry_price'] = self.inquiry_price.to_alipay_dict()
             else:
                 params['inquiry_price'] = self.inquiry_price
+        if self.inquiry_status:
+            if hasattr(self.inquiry_status, 'to_alipay_dict'):
+                params['inquiry_status'] = self.inquiry_status.to_alipay_dict()
+            else:
+                params['inquiry_status'] = self.inquiry_status
         if self.inquiry_type:
             if hasattr(self.inquiry_type, 'to_alipay_dict'):
                 params['inquiry_type'] = self.inquiry_type.to_alipay_dict()
@@ -103,6 +124,11 @@ class InquiryChannel(object):
                 params['register_flag'] = self.register_flag.to_alipay_dict()
             else:
                 params['register_flag'] = self.register_flag
+        if self.service_duration:
+            if hasattr(self.service_duration, 'to_alipay_dict'):
+                params['service_duration'] = self.service_duration.to_alipay_dict()
+            else:
+                params['service_duration'] = self.service_duration
         return params
 
     @staticmethod
@@ -116,12 +142,16 @@ class InquiryChannel(object):
             o.inquiry_mode = d['inquiry_mode']
         if 'inquiry_price' in d:
             o.inquiry_price = d['inquiry_price']
+        if 'inquiry_status' in d:
+            o.inquiry_status = d['inquiry_status']
         if 'inquiry_type' in d:
             o.inquiry_type = d['inquiry_type']
         if 'inquiry_url' in d:
             o.inquiry_url = d['inquiry_url']
         if 'register_flag' in d:
             o.register_flag = d['register_flag']
+        if 'service_duration' in d:
+            o.service_duration = d['service_duration']
         return o
 
 
