@@ -8,10 +8,18 @@ from alipay.aop.api.constant.ParamConstants import *
 class MemberCardOperator(object):
 
     def __init__(self):
+        self._ext_op_id = None
         self._op_id = None
         self._op_type = None
 
     @property
+    def ext_op_id(self):
+        return self._ext_op_id
+
+    @ext_op_id.setter
+    def ext_op_id(self, value):
+        self._ext_op_id = value
+    @property
     def op_id(self):
         return self._op_id
 
@@ -29,6 +37,11 @@ class MemberCardOperator(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.ext_op_id:
+            if hasattr(self.ext_op_id, 'to_alipay_dict'):
+                params['ext_op_id'] = self.ext_op_id.to_alipay_dict()
+            else:
+                params['ext_op_id'] = self.ext_op_id
         if self.op_id:
             if hasattr(self.op_id, 'to_alipay_dict'):
                 params['op_id'] = self.op_id.to_alipay_dict()
@@ -46,6 +59,8 @@ class MemberCardOperator(object):
         if not d:
             return None
         o = MemberCardOperator()
+        if 'ext_op_id' in d:
+            o.ext_op_id = d['ext_op_id']
         if 'op_id' in d:
             o.op_id = d['op_id']
         if 'op_type' in d:
