@@ -8,10 +8,18 @@ from alipay.aop.api.constant.ParamConstants import *
 class MiniAppCustomGrayGroupDto(object):
 
     def __init__(self):
+        self._id = None
         self._name = None
         self._rule_code = None
 
     @property
+    def id(self):
+        return self._id
+
+    @id.setter
+    def id(self, value):
+        self._id = value
+    @property
     def name(self):
         return self._name
 
@@ -29,6 +37,11 @@ class MiniAppCustomGrayGroupDto(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.id:
+            if hasattr(self.id, 'to_alipay_dict'):
+                params['id'] = self.id.to_alipay_dict()
+            else:
+                params['id'] = self.id
         if self.name:
             if hasattr(self.name, 'to_alipay_dict'):
                 params['name'] = self.name.to_alipay_dict()
@@ -46,6 +59,8 @@ class MiniAppCustomGrayGroupDto(object):
         if not d:
             return None
         o = MiniAppCustomGrayGroupDto()
+        if 'id' in d:
+            o.id = d['id']
         if 'name' in d:
             o.name = d['name']
         if 'rule_code' in d:
