@@ -20,7 +20,10 @@ class MpcpromoGoodsList(object):
         self._detail_pic_num = None
         self._free_shipping = None
         self._fresh_degree = None
+        self._host_app_id = None
         self._id = None
+        self._material_list = None
+        self._order_url = None
         self._origin_price = None
         self._pic_url_list = None
         self._price_unit = None
@@ -132,6 +135,13 @@ class MpcpromoGoodsList(object):
     def fresh_degree(self, value):
         self._fresh_degree = value
     @property
+    def host_app_id(self):
+        return self._host_app_id
+
+    @host_app_id.setter
+    def host_app_id(self, value):
+        self._host_app_id = value
+    @property
     def id(self):
         return self._id
 
@@ -139,6 +149,23 @@ class MpcpromoGoodsList(object):
     def id(self, value):
         self._id = value
     @property
+    def material_list(self):
+        return self._material_list
+
+    @material_list.setter
+    def material_list(self, value):
+        if isinstance(value, list):
+            self._material_list = list()
+            for i in value:
+                self._material_list.append(i)
+    @property
+    def order_url(self):
+        return self._order_url
+
+    @order_url.setter
+    def order_url(self, value):
+        self._order_url = value
+    @property
     def origin_price(self):
         return self._origin_price
 
@@ -370,11 +397,31 @@ class MpcpromoGoodsList(object):
                 params['fresh_degree'] = self.fresh_degree.to_alipay_dict()
             else:
                 params['fresh_degree'] = self.fresh_degree
+        if self.host_app_id:
+            if hasattr(self.host_app_id, 'to_alipay_dict'):
+                params['host_app_id'] = self.host_app_id.to_alipay_dict()
+            else:
+                params['host_app_id'] = self.host_app_id
         if self.id:
             if hasattr(self.id, 'to_alipay_dict'):
                 params['id'] = self.id.to_alipay_dict()
             else:
                 params['id'] = self.id
+        if self.material_list:
+            if isinstance(self.material_list, list):
+                for i in range(0, len(self.material_list)):
+                    element = self.material_list[i]
+                    if hasattr(element, 'to_alipay_dict'):
+                        self.material_list[i] = element.to_alipay_dict()
+            if hasattr(self.material_list, 'to_alipay_dict'):
+                params['material_list'] = self.material_list.to_alipay_dict()
+            else:
+                params['material_list'] = self.material_list
+        if self.order_url:
+            if hasattr(self.order_url, 'to_alipay_dict'):
+                params['order_url'] = self.order_url.to_alipay_dict()
+            else:
+                params['order_url'] = self.order_url
         if self.origin_price:
             if hasattr(self.origin_price, 'to_alipay_dict'):
                 params['origin_price'] = self.origin_price.to_alipay_dict()
@@ -531,8 +578,14 @@ class MpcpromoGoodsList(object):
             o.free_shipping = d['free_shipping']
         if 'fresh_degree' in d:
             o.fresh_degree = d['fresh_degree']
+        if 'host_app_id' in d:
+            o.host_app_id = d['host_app_id']
         if 'id' in d:
             o.id = d['id']
+        if 'material_list' in d:
+            o.material_list = d['material_list']
+        if 'order_url' in d:
+            o.order_url = d['order_url']
         if 'origin_price' in d:
             o.origin_price = d['origin_price']
         if 'pic_url_list' in d:
