@@ -3,21 +3,37 @@
 import json
 
 from alipay.aop.api.constant.ParamConstants import *
+from alipay.aop.api.domain.GroupBuyInfo import GroupBuyInfo
 from alipay.aop.api.domain.OrderItemInfoVO import OrderItemInfoVO
+from alipay.aop.api.domain.OrderTagInfo import OrderTagInfo
 from alipay.aop.api.domain.PayInfoVO import PayInfoVO
 from alipay.aop.api.domain.PriceInfoVO import PriceInfoVO
 from alipay.aop.api.domain.PromoApplyInfoVO import PromoApplyInfoVO
+from alipay.aop.api.domain.PromoInfoVO import PromoInfoVO
 
 
 class OrderDetailInfoVO(object):
 
     def __init__(self):
+        self._group_buy_info = None
         self._item_infos = None
+        self._order_tag_info = None
         self._pay_info = None
         self._price_info = None
         self._promo_apply_info = None
+        self._promo_info = None
 
     @property
+    def group_buy_info(self):
+        return self._group_buy_info
+
+    @group_buy_info.setter
+    def group_buy_info(self, value):
+        if isinstance(value, GroupBuyInfo):
+            self._group_buy_info = value
+        else:
+            self._group_buy_info = GroupBuyInfo.from_alipay_dict(value)
+    @property
     def item_infos(self):
         return self._item_infos
 
@@ -31,6 +47,16 @@ class OrderDetailInfoVO(object):
                 else:
                     self._item_infos.append(OrderItemInfoVO.from_alipay_dict(i))
     @property
+    def order_tag_info(self):
+        return self._order_tag_info
+
+    @order_tag_info.setter
+    def order_tag_info(self, value):
+        if isinstance(value, OrderTagInfo):
+            self._order_tag_info = value
+        else:
+            self._order_tag_info = OrderTagInfo.from_alipay_dict(value)
+    @property
     def pay_info(self):
         return self._pay_info
 
@@ -60,10 +86,25 @@ class OrderDetailInfoVO(object):
             self._promo_apply_info = value
         else:
             self._promo_apply_info = PromoApplyInfoVO.from_alipay_dict(value)
+    @property
+    def promo_info(self):
+        return self._promo_info
+
+    @promo_info.setter
+    def promo_info(self, value):
+        if isinstance(value, PromoInfoVO):
+            self._promo_info = value
+        else:
+            self._promo_info = PromoInfoVO.from_alipay_dict(value)
 
 
     def to_alipay_dict(self):
         params = dict()
+        if self.group_buy_info:
+            if hasattr(self.group_buy_info, 'to_alipay_dict'):
+                params['group_buy_info'] = self.group_buy_info.to_alipay_dict()
+            else:
+                params['group_buy_info'] = self.group_buy_info
         if self.item_infos:
             if isinstance(self.item_infos, list):
                 for i in range(0, len(self.item_infos)):
@@ -74,6 +115,11 @@ class OrderDetailInfoVO(object):
                 params['item_infos'] = self.item_infos.to_alipay_dict()
             else:
                 params['item_infos'] = self.item_infos
+        if self.order_tag_info:
+            if hasattr(self.order_tag_info, 'to_alipay_dict'):
+                params['order_tag_info'] = self.order_tag_info.to_alipay_dict()
+            else:
+                params['order_tag_info'] = self.order_tag_info
         if self.pay_info:
             if hasattr(self.pay_info, 'to_alipay_dict'):
                 params['pay_info'] = self.pay_info.to_alipay_dict()
@@ -89,6 +135,11 @@ class OrderDetailInfoVO(object):
                 params['promo_apply_info'] = self.promo_apply_info.to_alipay_dict()
             else:
                 params['promo_apply_info'] = self.promo_apply_info
+        if self.promo_info:
+            if hasattr(self.promo_info, 'to_alipay_dict'):
+                params['promo_info'] = self.promo_info.to_alipay_dict()
+            else:
+                params['promo_info'] = self.promo_info
         return params
 
     @staticmethod
@@ -96,14 +147,20 @@ class OrderDetailInfoVO(object):
         if not d:
             return None
         o = OrderDetailInfoVO()
+        if 'group_buy_info' in d:
+            o.group_buy_info = d['group_buy_info']
         if 'item_infos' in d:
             o.item_infos = d['item_infos']
+        if 'order_tag_info' in d:
+            o.order_tag_info = d['order_tag_info']
         if 'pay_info' in d:
             o.pay_info = d['pay_info']
         if 'price_info' in d:
             o.price_info = d['price_info']
         if 'promo_apply_info' in d:
             o.promo_apply_info = d['promo_apply_info']
+        if 'promo_info' in d:
+            o.promo_info = d['promo_info']
         return o
 
 
