@@ -11,8 +11,11 @@ class PriceInfoDTO(object):
         self._additional_price = None
         self._discounted_price = None
         self._freight = None
+        self._max_order_price = None
         self._merchant_value_price = None
+        self._min_order_price = None
         self._order_price = None
+        self._price_mode = None
 
     @property
     def additional_price(self):
@@ -36,6 +39,13 @@ class PriceInfoDTO(object):
     def freight(self, value):
         self._freight = value
     @property
+    def max_order_price(self):
+        return self._max_order_price
+
+    @max_order_price.setter
+    def max_order_price(self, value):
+        self._max_order_price = value
+    @property
     def merchant_value_price(self):
         return self._merchant_value_price
 
@@ -43,12 +53,26 @@ class PriceInfoDTO(object):
     def merchant_value_price(self, value):
         self._merchant_value_price = value
     @property
+    def min_order_price(self):
+        return self._min_order_price
+
+    @min_order_price.setter
+    def min_order_price(self, value):
+        self._min_order_price = value
+    @property
     def order_price(self):
         return self._order_price
 
     @order_price.setter
     def order_price(self, value):
         self._order_price = value
+    @property
+    def price_mode(self):
+        return self._price_mode
+
+    @price_mode.setter
+    def price_mode(self, value):
+        self._price_mode = value
 
 
     def to_alipay_dict(self):
@@ -68,16 +92,31 @@ class PriceInfoDTO(object):
                 params['freight'] = self.freight.to_alipay_dict()
             else:
                 params['freight'] = self.freight
+        if self.max_order_price:
+            if hasattr(self.max_order_price, 'to_alipay_dict'):
+                params['max_order_price'] = self.max_order_price.to_alipay_dict()
+            else:
+                params['max_order_price'] = self.max_order_price
         if self.merchant_value_price:
             if hasattr(self.merchant_value_price, 'to_alipay_dict'):
                 params['merchant_value_price'] = self.merchant_value_price.to_alipay_dict()
             else:
                 params['merchant_value_price'] = self.merchant_value_price
+        if self.min_order_price:
+            if hasattr(self.min_order_price, 'to_alipay_dict'):
+                params['min_order_price'] = self.min_order_price.to_alipay_dict()
+            else:
+                params['min_order_price'] = self.min_order_price
         if self.order_price:
             if hasattr(self.order_price, 'to_alipay_dict'):
                 params['order_price'] = self.order_price.to_alipay_dict()
             else:
                 params['order_price'] = self.order_price
+        if self.price_mode:
+            if hasattr(self.price_mode, 'to_alipay_dict'):
+                params['price_mode'] = self.price_mode.to_alipay_dict()
+            else:
+                params['price_mode'] = self.price_mode
         return params
 
     @staticmethod
@@ -91,10 +130,16 @@ class PriceInfoDTO(object):
             o.discounted_price = d['discounted_price']
         if 'freight' in d:
             o.freight = d['freight']
+        if 'max_order_price' in d:
+            o.max_order_price = d['max_order_price']
         if 'merchant_value_price' in d:
             o.merchant_value_price = d['merchant_value_price']
+        if 'min_order_price' in d:
+            o.min_order_price = d['min_order_price']
         if 'order_price' in d:
             o.order_price = d['order_price']
+        if 'price_mode' in d:
+            o.price_mode = d['price_mode']
         return o
 
 
