@@ -17,6 +17,7 @@ from alipay.aop.api.domain.OrderGoodsDTO import OrderGoodsDTO
 class ReceiptOrderDTO(object):
 
     def __init__(self):
+        self._alipay_open_id = None
         self._alipay_uid = None
         self._amount = None
         self._belong_merchant_info = None
@@ -52,6 +53,13 @@ class ReceiptOrderDTO(object):
         self._trade_type = None
 
     @property
+    def alipay_open_id(self):
+        return self._alipay_open_id
+
+    @alipay_open_id.setter
+    def alipay_open_id(self, value):
+        self._alipay_open_id = value
+    @property
     def alipay_uid(self):
         return self._alipay_uid
 
@@ -334,6 +342,11 @@ class ReceiptOrderDTO(object):
 
     def to_alipay_dict(self):
         params = dict()
+        if self.alipay_open_id:
+            if hasattr(self.alipay_open_id, 'to_alipay_dict'):
+                params['alipay_open_id'] = self.alipay_open_id.to_alipay_dict()
+            else:
+                params['alipay_open_id'] = self.alipay_open_id
         if self.alipay_uid:
             if hasattr(self.alipay_uid, 'to_alipay_dict'):
                 params['alipay_uid'] = self.alipay_uid.to_alipay_dict()
@@ -541,6 +554,8 @@ class ReceiptOrderDTO(object):
         if not d:
             return None
         o = ReceiptOrderDTO()
+        if 'alipay_open_id' in d:
+            o.alipay_open_id = d['alipay_open_id']
         if 'alipay_uid' in d:
             o.alipay_uid = d['alipay_uid']
         if 'amount' in d:
