@@ -20,6 +20,7 @@ class AlipayOpenMiniVersionAuditApplyRequest(object):
         self._app_slogan = None
         self._app_version = None
         self._audit_rule = None
+        self._auto_online = None
         self._bundle_id = None
         self._license_name = None
         self._license_no = None
@@ -30,6 +31,7 @@ class AlipayOpenMiniVersionAuditApplyRequest(object):
         self._service_email = None
         self._service_phone = None
         self._service_region_info = None
+        self._speed_up = None
         self._test_accout = None
         self._test_password = None
         self._version_desc = None
@@ -116,6 +118,13 @@ class AlipayOpenMiniVersionAuditApplyRequest(object):
     def audit_rule(self, value):
         self._audit_rule = value
     @property
+    def auto_online(self):
+        return self._auto_online
+
+    @auto_online.setter
+    def auto_online(self, value):
+        self._auto_online = value
+    @property
     def bundle_id(self):
         return self._bundle_id
 
@@ -192,6 +201,13 @@ class AlipayOpenMiniVersionAuditApplyRequest(object):
                 else:
                     self._service_region_info.append(RegionInfo.from_alipay_dict(i))
     @property
+    def speed_up(self):
+        return self._speed_up
+
+    @speed_up.setter
+    def speed_up(self, value):
+        self._speed_up = value
+    @property
     def test_accout(self):
         return self._test_accout
 
@@ -470,6 +486,11 @@ class AlipayOpenMiniVersionAuditApplyRequest(object):
                 params['audit_rule'] = json.dumps(obj=self.audit_rule.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
             else:
                 params['audit_rule'] = self.audit_rule
+        if self.auto_online:
+            if hasattr(self.auto_online, 'to_alipay_dict'):
+                params['auto_online'] = json.dumps(obj=self.auto_online.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
+            else:
+                params['auto_online'] = self.auto_online
         if self.bundle_id:
             if hasattr(self.bundle_id, 'to_alipay_dict'):
                 params['bundle_id'] = json.dumps(obj=self.bundle_id.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
@@ -522,6 +543,11 @@ class AlipayOpenMiniVersionAuditApplyRequest(object):
                     if hasattr(element, 'to_alipay_dict'):
                         self.service_region_info[i] = element.to_alipay_dict()
                 params['service_region_info'] = json.dumps(obj=self.service_region_info, ensure_ascii=False, sort_keys=True, separators=(',', ':'))
+        if self.speed_up:
+            if hasattr(self.speed_up, 'to_alipay_dict'):
+                params['speed_up'] = json.dumps(obj=self.speed_up.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
+            else:
+                params['speed_up'] = self.speed_up
         if self.test_accout:
             if hasattr(self.test_accout, 'to_alipay_dict'):
                 params['test_accout'] = json.dumps(obj=self.test_accout.to_alipay_dict(), ensure_ascii=False, sort_keys=True, separators=(',', ':'))
