@@ -11,6 +11,7 @@ class AlipayCommerceEcEmployeeAddResponse(AlipayResponse):
         super(AlipayCommerceEcEmployeeAddResponse, self).__init__()
         self._employee_id = None
         self._iot_unique_id = None
+        self._share_code = None
         self._sign_url = None
 
     @property
@@ -28,6 +29,13 @@ class AlipayCommerceEcEmployeeAddResponse(AlipayResponse):
     def iot_unique_id(self, value):
         self._iot_unique_id = value
     @property
+    def share_code(self):
+        return self._share_code
+
+    @share_code.setter
+    def share_code(self, value):
+        self._share_code = value
+    @property
     def sign_url(self):
         return self._sign_url
 
@@ -41,5 +49,7 @@ class AlipayCommerceEcEmployeeAddResponse(AlipayResponse):
             self.employee_id = response['employee_id']
         if 'iot_unique_id' in response:
             self.iot_unique_id = response['iot_unique_id']
+        if 'share_code' in response:
+            self.share_code = response['share_code']
         if 'sign_url' in response:
             self.sign_url = response['sign_url']
