@@ -9,10 +9,18 @@ class AlipayCommerceEcTransAccountTransferResponse(AlipayResponse):
 
     def __init__(self):
         super(AlipayCommerceEcTransAccountTransferResponse, self).__init__()
+        self._fund_order_id = None
         self._order_no = None
         self._status = None
 
     @property
+    def fund_order_id(self):
+        return self._fund_order_id
+
+    @fund_order_id.setter
+    def fund_order_id(self, value):
+        self._fund_order_id = value
+    @property
     def order_no(self):
         return self._order_no
 
@@ -29,6 +37,8 @@ class AlipayCommerceEcTransAccountTransferResponse(AlipayResponse):
 
     def parse_response_content(self, response_content):
         response = super(AlipayCommerceEcTransAccountTransferResponse, self).parse_response_content(response_content)
+        if 'fund_order_id' in response:
+            self.fund_order_id = response['fund_order_id']
         if 'order_no' in response:
             self.order_no = response['order_no']
         if 'status' in response:
