@@ -10,6 +10,8 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyResponse(AlipayResponse)
     def __init__(self):
         super(AlipayCommerceTransportEtcApplyorderCreateormodifyResponse, self).__init__()
         self._alipay_order_id = None
+        self._biz_code = None
+        self._biz_msg = None
 
     @property
     def alipay_order_id(self):
@@ -18,8 +20,26 @@ class AlipayCommerceTransportEtcApplyorderCreateormodifyResponse(AlipayResponse)
     @alipay_order_id.setter
     def alipay_order_id(self, value):
         self._alipay_order_id = value
+    @property
+    def biz_code(self):
+        return self._biz_code
+
+    @biz_code.setter
+    def biz_code(self, value):
+        self._biz_code = value
+    @property
+    def biz_msg(self):
+        return self._biz_msg
+
+    @biz_msg.setter
+    def biz_msg(self, value):
+        self._biz_msg = value
 
     def parse_response_content(self, response_content):
         response = super(AlipayCommerceTransportEtcApplyorderCreateormodifyResponse, self).parse_response_content(response_content)
         if 'alipay_order_id' in response:
             self.alipay_order_id = response['alipay_order_id']
+        if 'biz_code' in response:
+            self.biz_code = response['biz_code']
+        if 'biz_msg' in response:
+            self.biz_msg = response['biz_msg']
