@@ -12,6 +12,7 @@ class AlipayCommerceTransportParkingEnterinfoSyncResponse(AlipayResponse):
         self._agreement_scene = None
         self._biz_code = None
         self._biz_msg = None
+        self._serial_no = None
 
     @property
     def agreement_scene(self):
@@ -34,6 +35,13 @@ class AlipayCommerceTransportParkingEnterinfoSyncResponse(AlipayResponse):
     @biz_msg.setter
     def biz_msg(self, value):
         self._biz_msg = value
+    @property
+    def serial_no(self):
+        return self._serial_no
+
+    @serial_no.setter
+    def serial_no(self, value):
+        self._serial_no = value
 
     def parse_response_content(self, response_content):
         response = super(AlipayCommerceTransportParkingEnterinfoSyncResponse, self).parse_response_content(response_content)
@@ -43,3 +51,5 @@ class AlipayCommerceTransportParkingEnterinfoSyncResponse(AlipayResponse):
             self.biz_code = response['biz_code']
         if 'biz_msg' in response:
             self.biz_msg = response['biz_msg']
+        if 'serial_no' in response:
+            self.serial_no = response['serial_no']
