@@ -9,11 +9,19 @@ class AlipayFincoreComplianceSignStatusQueryResponse(AlipayResponse):
 
     def __init__(self):
         super(AlipayFincoreComplianceSignStatusQueryResponse, self).__init__()
+        self._archived_file_http_url = None
         self._business_id = None
         self._comment = None
         self._status = None
 
     @property
+    def archived_file_http_url(self):
+        return self._archived_file_http_url
+
+    @archived_file_http_url.setter
+    def archived_file_http_url(self, value):
+        self._archived_file_http_url = value
+    @property
     def business_id(self):
         return self._business_id
 
@@ -37,6 +45,8 @@ class AlipayFincoreComplianceSignStatusQueryResponse(AlipayResponse):
 
     def parse_response_content(self, response_content):
         response = super(AlipayFincoreComplianceSignStatusQueryResponse, self).parse_response_content(response_content)
+        if 'archived_file_http_url' in response:
+            self.archived_file_http_url = response['archived_file_http_url']
         if 'business_id' in response:
             self.business_id = response['business_id']
         if 'comment' in response:
