@@ -15,8 +15,10 @@ class AlipayFundAuthOrderAppFreezeResponse(AlipayResponse):
         self._fund_amount = None
         self._gmt_trans = None
         self._operation_id = None
+        self._orderStr = None
         self._out_order_no = None
         self._out_request_no = None
+        self._payer_open_id = None
         self._payer_user_id = None
         self._pre_auth_type = None
         self._status = None
@@ -65,6 +67,13 @@ class AlipayFundAuthOrderAppFreezeResponse(AlipayResponse):
     def operation_id(self, value):
         self._operation_id = value
     @property
+    def orderStr(self):
+        return self._orderStr
+
+    @orderStr.setter
+    def orderStr(self, value):
+        self._orderStr = value
+    @property
     def out_order_no(self):
         return self._out_order_no
 
@@ -79,6 +88,13 @@ class AlipayFundAuthOrderAppFreezeResponse(AlipayResponse):
     def out_request_no(self, value):
         self._out_request_no = value
     @property
+    def payer_open_id(self):
+        return self._payer_open_id
+
+    @payer_open_id.setter
+    def payer_open_id(self, value):
+        self._payer_open_id = value
+    @property
     def payer_user_id(self):
         return self._payer_user_id
 
@@ -121,10 +137,14 @@ class AlipayFundAuthOrderAppFreezeResponse(AlipayResponse):
             self.gmt_trans = response['gmt_trans']
         if 'operation_id' in response:
             self.operation_id = response['operation_id']
+        if 'orderStr' in response:
+            self.orderStr = response['orderStr']
         if 'out_order_no' in response:
             self.out_order_no = response['out_order_no']
         if 'out_request_no' in response:
             self.out_request_no = response['out_request_no']
+        if 'payer_open_id' in response:
+            self.payer_open_id = response['payer_open_id']
         if 'payer_user_id' in response:
             self.payer_user_id = response['payer_user_id']
         if 'pre_auth_type' in response:
