@@ -9,10 +9,18 @@ class DatadigitalFincloudGeneralsaasFaceCertifyCertifyResponse(AlipayResponse):
 
     def __init__(self):
         super(DatadigitalFincloudGeneralsaasFaceCertifyCertifyResponse, self).__init__()
+        self._extern_info = None
         self._mismatch_reason = None
         self._passed = None
 
     @property
+    def extern_info(self):
+        return self._extern_info
+
+    @extern_info.setter
+    def extern_info(self, value):
+        self._extern_info = value
+    @property
     def mismatch_reason(self):
         return self._mismatch_reason
 
@@ -29,6 +37,8 @@ class DatadigitalFincloudGeneralsaasFaceCertifyCertifyResponse(AlipayResponse):
 
     def parse_response_content(self, response_content):
         response = super(DatadigitalFincloudGeneralsaasFaceCertifyCertifyResponse, self).parse_response_content(response_content)
+        if 'extern_info' in response:
+            self.extern_info = response['extern_info']
         if 'mismatch_reason' in response:
             self.mismatch_reason = response['mismatch_reason']
         if 'passed' in response:
